@@ -56,8 +56,6 @@ class Pipeline(ABC):
             #downloading files
             self.log(Severity.INFO, "downloading files...")
             data["files"] = self.download_input_files()
-            # if len(data['files']) < 5:
-            #     raise FileNotFoundError("Not enough files provided for this pipeline")
             #running abstract run method
             self.run(data)
             #setting pipeline to DONE when finished
@@ -102,8 +100,11 @@ class Pipeline(ABC):
             "logs": upload_log_files[0],
             "userLogs": upload_log_files[1]
         }
+        # Iterates over all the result files and adds them as an edge to the pipelineRun
+        for item in self.result_files:
+            self.seams.attach_edges(self.tenant_id, self.vertex_id, "Has Result File", [item["id"]])
         return self.seams.update_vertex(self.tenant_id, self.vertex_id, "PipelineRun", attributes)
-
+        
 
     def update_pipeline_status_error(self):
         '''
@@ -119,6 +120,9 @@ class Pipeline(ABC):
             "logs": upload_log_files[0],
             "userLogs": upload_log_files[1]
         }
+        # Iterates over all the result files and adds them as an edge to the pipelineRun
+        for item in self.result_files:
+            self.seams.attach_edges(self.tenant_id, self.vertex_id, "Has Result File", [item["id"]])
         return self.seams.update_vertex(self.tenant_id, self.vertex_id, "PipelineRun", attributes)
 
 
@@ -132,8 +136,9 @@ class Pipeline(ABC):
         #gets the run parameters of the pipeline
         data = json.loads(self.seams.get_vertex_by_id(self.tenant_id, self.vertex_id)["runParameters"])
         files = []
-        #downloads files in pipeline, adds them to a temp file, adds file path to a list
+        #downloads files in pipeline, adds them to a temp file, adds file path to a list, attaches file vertices to pipelineRun
         for item in data["Files"]:
+            self.seams.attach_edges(self.tenant_id, self.vertex_id, "Has Input File", [item['vertexId']])
             download = self.seams.download_files(self.tenant_id, item["vertexId"])
             for item in download:
                 temp_file_full_path = os.path.join(tempfile.gettempdir(), item)
@@ -142,6 +147,38 @@ class Pipeline(ABC):
                 f.write(download[item])
                 f.close()
         return files
+
+
+    def create_chart_from_file(self, parent_vertex_id, file_vertex_id, chart_name, x_label_column, y_label_column, chart_type):
+        '''
+        Creates a chart vertex type and attaches an edge to connect it to the parent
+
+        :param parent_vertex_id:
+            Vertex id of the vertex the edge is coming from
+        :param file_vertex_id:
+            Vertex id of the file you want to create the chart from
+        :param chart_name"
+            Name of the chart, this will also be the name of the Chart vertex (something like "Pressure vs Time")
+        :param x_label_column:
+            X data column name
+        :param  y_label_column:
+            Y data column name
+        :param chart_type:
+            Type of chart to display "line", "pie", "doughnut", "scatter", "vertical", "horizontal" (last two are different types of bar charts)
+
+        :returns (edge_result, chart_vertex_id): 
+            Tuple of edge connection result and new chart vertex id
+        '''
+        attributes = {
+            "datasource_file_id": file_vertex_id,
+            "title": chart_name,
+            "dataset_1_labels_column": x_label_column,
+            "dataset_1_values_column": y_label_column,
+            "type": chart_type
+        }
+        chart_vertex = self.seams.create_vertex(self.tenant_id, "Chart", chart_name, attributes)
+        edge_result = self.seams.attach_edges(self.tenant_id, parent_vertex_id, "Charts", [chart_vertex["id"]])
+        return (edge_result, chart_vertex["id"])
     
 
     def upload_files(self, caption, files, file_type):
