@@ -1,14 +1,10 @@
 #!/usr/bin/env python
 from requests import Request, Session
 from itertools import islice
-import sys
 import mimetypes
-sys.path.append( '.\\seams\\' )
-sys.path.append( '.\\' )
 from seams.exceptions import SeamsException, SeamsAPIException
 import json
 import msal
-import os
 
 class Seams(object):
     '''
@@ -40,9 +36,6 @@ class Seams(object):
         :returns:
             None
         '''
-        self.secret = secret
-        self.app_id = app_id
-        self.tenant_id = tenant_id
         app = msal.ConfidentialClientApplication(
                 app_id,
                 authority="https://login.microsoftonline.com/{}".format(tenant_id),
@@ -64,7 +57,6 @@ class Seams(object):
         Disconnect from the Seams API 
         '''
         self.bearer = None
-        self.secret = None
         self.connected = False
 
 
@@ -95,10 +87,7 @@ class Seams(object):
             response = {
                 'bearer': self.bearer,
                 'url': self.URL,
-                'connected': self.connected,
-                'secret': self.secret,
-                'app_id': self.app_id,
-                'tenant_id': self.tenant_id
+                'connected': self.connected
             }
             return response
         except:
